# Schedules Tools
Library to handle various schedule sources and storage

## Tests
Smartsheet tests need SMARTSHEET_API_TOKEN env variable.
Run as either:
- tox
- tox -e py
- tox -e py specific.test
- tox -p
- pytest
- pytest specific.test

To regenerate test data:
- tox -e regenerate
